@@ -1,10 +1,10 @@
 from wagtail.core import blocks
 
-from ... import constants
-from ..common import BaseBlock
+from webspace.cms import constants
+from webspace.cms.blocks.common import EntryBlock
 
 
-class Articles(BaseBlock):
+class ArticlesEntry(EntryBlock):
     articles = blocks.StreamBlock(
         [
             ('article', blocks.PageChooserBlock(required=False, target_model='cms.BlogPage')),
