@@ -1,9 +1,26 @@
 from wagtail.core import blocks
+from wagtail.snippets.blocks import SnippetChooserBlock
 
 from webspace.cms import constants
 from webspace.cms.blocks.common import \
     TextBlock, \
-    EntryBlock
+    EntryBlock, \
+    ButtonBlock
+
+
+class TimelineCustomBlock(TextBlock):
+    icon = SnippetChooserBlock('cms.IconSnippet', required=True)
+    buttons = blocks.StreamBlock(
+        [
+            ('button', ButtonBlock()),
+        ],
+        max_num=3,
+        required=False
+    )
+
+    class Meta:
+        template = '%s/common/text.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Custom"
 
 
 class TimeLineEntry(EntryBlock):
@@ -11,6 +28,7 @@ class TimeLineEntry(EntryBlock):
     items = blocks.StreamBlock(
         [
             ('text', TextBlock()),
+            ('custom', TimelineCustomBlock()),
         ],
         min_num=1
     )
