@@ -40,6 +40,7 @@ FormEntry = get_class('cms.blocks.entries', 'FormEntry')
 PortfoliosEntry = get_class('cms.blocks.entries', 'PortfoliosEntry')
 GalleryEntry = get_class('cms.blocks.entries', 'GalleryEntry')
 StreamContentEntry = get_class('cms.blocks.entries', 'StreamContentEntry')
+GallerySliderEntry = get_class('cms.blocks.entries', 'GallerySliderEntry')
 
 
 
@@ -140,7 +141,8 @@ class AGenericPage(Page):
         ('form', FormEntry()),
         ('portfolios', PortfoliosEntry()),
         ('gallery', GalleryEntry()),
-        ('stream_content', StreamContentEntry())
+        ('gallery_slider', GallerySliderEntry()),
+        ('stream_content', StreamContentEntry()),
     ], blank=True)
 
     content_panels = [
